<?php

class WP_MailChimp_Form {

    public $MailChimp_options;
    public $MailChimp_defaultSettings;
    public $MailChimp_optionName = array(
        'options' => 'wp_MailChimp_form_options',
        'lists' => 'wp_MailChimp_form_lists',
        'users' => 'wp_MailChimp_form_users',
    );

    function __construct() {
        /*
         * set plugin default options
         */
        $this->MailChimp_defaultSettings = array();
        if (!is_array(get_option($this->MailChimp_optionName['options'])) or !is_array(get_option($this->MailChimp_optionName['lists'])) or !is_array(get_option($this->MailChimp_optionName['users']))) {
            foreach ($this->MailChimp_optionName as $key => $value) {
                add_option($value, $this->MailChimp_defaultSettings);
            }
        }
        /*
         * load plugin actions
         */
        add_action('admin_menu', array(
            $this,
            'add_menu'
        ));
        add_action('admin_head', array(
            $this,
            'admin_head'
        ));
        add_action('wp_head', array(
            $this,
            'front_head'
        ));
        add_action('widgets_init', array(
            $this,
            'add_widget_form'
        ));
    }

    // add this wp menu
    public function add_menu() {
        add_options_page(esc_html__('MailChimp Form', 'mailchimp-form'), esc_html__('MailChimp Form', 'mailchimp-form'), 'manage_options', 'mailchimp-widget-form', array(
            $this,
            'MailChimp_optionPage'
        ), null, 50);
    }

    public function add_widget_form() {
        register_widget('MailChimp_widget_form');
    }

    // add CSS and JavaScript to admin head
    public function admin_head() {
        wp_enqueue_style('mailchimp-style', MailChimp_URL . 'assets/css/mailchimp-style.css', false);
        wp_enqueue_script('mailchimp-minicolors-js', MailChimp_URL . 'assets/js/mini-colors/minicolors.min.js', array('jquery'));
        wp_enqueue_script('mailchimp-custom-js', MailChimp_URL . 'assets/js/mailchimp-scripts.js', array('jquery'));
    }

    // add CSS and JavaScript to front head
    public function front_head() {
        wp_enqueue_style('mailchimp-style', MailChimp_URL . 'assets/css/mailchimp-style.css',  array(), '1.1', 'all');
        wp_enqueue_script('mailchimp-custom-js', MailChimp_URL . 'assets/js/mailchimp-scripts.js', array('jquery'));
    }

    // show admin messages
    public function show_adminMessages() {
        $plugin_messages = array();
        $plugin_messages[] = esc_html__('MailChimp has been saved setting', 'mailchimp-form');
        if (count($plugin_messages) > 0) {
            echo '<div id="message" class="notice notice-success is-dismissible">';
            foreach ($plugin_messages as $message) {
                echo '<p><strong>' . $message . '</strong></p>';
                echo '<button class="notice-dismiss" type="button"><span class="screen-reader-text">' . esc_html__('Dismiss this notice', 'mailchimp-form') . '</span></button>';
            }
            echo '</div>';
        }
    }

    // load option page
    public function MailChimp_optionPage() {
        include_once('options-template.php');
    }

    // get option value by key
    public function get_options($value, $key) {
        $MailChimp_option = get_option($this->MailChimp_optionName[$key]);
        return isset($MailChimp_option[$value]) ? $MailChimp_option[$value] : '';
    }

    public function save_options() {
        if (isset($_POST['mailchimpsave_option']) and !empty($_POST['mailchimpsave_option'])) {
            foreach ($_POST as $key => $value) {
                if ($key != 'mailchimpsave_option') {
                    $key_clean = str_replace('mailchimpsave_', '', $key);
                    $this->MailChimp_options["$key_clean"] = $_POST["$key"];
                }
            }
            update_option($this->MailChimp_optionName['options'], $this->MailChimp_options);
            add_action('admin_notices', array(
                $this,
                'show_adminMessages'
            ));
        }
    }

}
