<?php

/*
 * To change this template file, choose Tools | Templates
 */

class MailChimp_VCExtendAddonClass extends WP_MailChimp_Form {

    public $lists_ids = [

    ];

    function __construct() {
        // We safely integrate with VC with this hook
        add_action('init', array(
            $this,
            'integrateWithVC'
        ));

        // Use this when creating a shortcode addon
        add_shortcode('mailchimp-form', array(
            $this,
            'renderMyMailchimp'
        ));

        // Register CSS and JS
        // add_action('wp_enqueue_scripts', array($this, 'loadCssAndJs'));
    }

    public function integrateWithVC() {
        // Check if Visual Composer is installed
        if (!defined('WPB_VC_VERSION')) {
            // Display notice that Visual Compser is required
            add_action('admin_notices', array(
                $this,
                'showVcVersionNotice'
            ));
            return;
        }

        // List ID
        $list_ids[esc_html__("Select List ID", 'mailchimp-form')] = '';
        for ($x = 1; $x <= $this->get_options('list_count', 'options'); $x++) {
            $list_ids[$this->get_options('list_name_' . $x, 'options')] = $this->get_options('list_id_' . $x, 'options');
        }

        /*
          Add your Visual Composer logic here.
          Lets call vc_map function to "register" our custom shortcode within Visual Composer interface.

          More info: http://kb.wpbakery.com/index.php?title=Vc_map
         */

        vc_map(array(
            "name" => esc_html__("MailChimp Form", 'mailchimp-form'),
            "description" => esc_html__("MailChimp subscribe form ", 'mailchimp-form'),
            "base" => "mailchimp-form",
            "class" => "mailchimp-form",
            "controls" => "full",
            "icon" => MailChimp_URL . 'assets/images/logo.png',
            // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => esc_html__('AH Addons', 'js_composer'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
                array(
                    "type" => "textfield",
                    "holder" => "div",
                    "class" => "",
                    "heading" => esc_html__("Widget Title", 'mailchimp-form'),
                    "param_name" => "widget_title",
                    "value" => $this->get_options('widget_body_title', 'options')
                    //"description" => esc_html__("Description for foo param.", 'mailchimp-form')
                ),
                array(
                    "type" => "dropdown",
                    "heading" => esc_html__("Default List", 'mailchimp-form'),
                    "param_name" => "list_id",
                    "admin_label" => true,
                    "value" => $list_ids
                ),
                array(
                    "type" => "colorpicker",
                    "holder" => "div",
                    "class" => "",
                    "heading" => esc_html__("Background Color", 'mailchimp-form'),
                    "param_name" => "bg_color",
                    "value" => '#f7941d',
                    //Default Red color
                    //"description" => esc_html__("Choose text color", 'mailchimp-form')
                ),
                array(
                    "type" => "colorpicker",
                    "holder" => "div",
                    "class" => "",
                    "heading" => esc_html__("Text Color", 'mailchimp-form'),
                    "param_name" => "text_color",
                    "value" => '#ffffff',
                    //Default Red color
                    //"description" => esc_html__("Choose text color", 'mailchimp-form')
                )
                /* array(
                  "type" => "textarea_html",
                  "holder" => "div",
                  "class" => "",
                  "heading" => esc_html__("Content", 'mailchimp-form'),
                  "param_name" => "content",
                  "value" => esc_html__("I am test text block. Click edit button to change this text.", 'mailchimp-form')
                  //"description" => esc_html__("Enter your content.", 'mailchimp-form')
                  ) */
            )
        ));
    }

    public function widgetForm($title, $list_id, $text_color) {
        $widget = '
        <form action="' . admin_url('admin-ajax.php') . '" method="post">
            <input type="hidden" name="mailchimp_listID" id="mailchimp_listID" value="' . $list_id . '">
            <p class="mailchimp_title" style="color:' . $text_color . ';"><i class="dashicons dashicons-email-alt"></i>  ' . $title . ' </p>';
        if ($this->get_options('allow_name', 'options') == 'true') {
            $widget .= '<div class="mailchimp-row">
                    <div class="mailchimp-col-5">
                        <input type="text" name="mailchimp_fname" id="mailchimp_fname" class="mailchimp_input" placeholder="' . esc_html__('First Name', 'mailchimp-form') . '">
                    </div>
                    <div class="mailchimp-col-5">
                        <input type="text" name="mailchimp_lname" id="mailchimp_lname" class="mailchimp_input" placeholder="' . esc_html__('Last Name', 'mailchimp-form') . '">
                    </div>
                </div>';
        }
        if ($this->get_options('allow_phone', 'options') == 'true') {
            $widget .= '<div class="mailchimp-row">
                    <div class="mailchimp-col-10">
                        <input type="text" name="mailchimp_phone" id="mailchimp_phone" class="mailchimp_input" placeholder="' . esc_html__('Phone Number', 'mailchimp-form') . '">
                    </div>
                </div>';
        }
        $widget .= '<input type="email" name="mailchimp_email" id="mailchimp_email" class="mailchimp_input" placeholder="' . esc_html__('Email', 'mailchimp-form') . '" required>
            <input type="submit" class="mailchimp_btn" value="' . esc_html__('Subscribe', 'mailchimp-form') . '">
        </form>
        <div class="loading" style="color: ' . $text_color . ';"><i class="dashicons dashicons-update"></i></div>
        <p class="mailchimp_msg" style="color:' . $text_color . ';"></p>';
        return $widget;
    }

    /*
      Shortcode logic how it should be rendered
     */

    public function renderMyMailchimp($atts, $content = null) {
        extract(shortcode_atts(array(
            'widget_title' => $this->get_options('widget_body_title', 'options'),
            'bg_color' => '#f7941d',
            'text_color' => '#ffffff',
            'list_id' => ''
        ), $atts));
        //$content = wpb_js_remove_wpautop($content, true); // fix unclosed/unwanted paragraph tags in $content
        $form = $this->widgetForm($widget_title, $list_id, $text_color);
        $output = "<div class='vc-mailchimp-form' style='background-color:{$bg_color}; color:{$text_color};'>{$form}</div>";
        //@$this->widgetForm($widget_title, $list_id, $text_color);
        return $output;
    }

    /*
      Load plugin css and javascript files which you may need on front end of your site
     */

    public function loadCssAndJs() {
        // wp_register_style('vc_extend_style', plugins_url('assets/vc_extend.css', __FILE__));
        //wp_enqueue_style('vc_extend_style');
        // If you need any javascript files on front end, here is how you can load them.
        //wp_enqueue_script( 'vc_extend_js', plugins_url('assets/vc_extend.js', __FILE__), array('jquery') );
    }

    /*
      Show notice if your plugin is activated but Visual Composer is not
     */

    public function showVcVersionNotice() {
        $plugin_data = get_plugin_data(__FILE__);
        echo '
        <div class="updated">
          <p>' . sprintf(__('<strong>%s</strong> requires <strong><a href="http://bit.ly/vcomposer" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'mailchimp-form'), $plugin_data['Name']) . '</p>
        </div>';
    }

}
