<?php

class MailChimp_widget_form extends WP_Widget {

    public $MailChimp_options;
    public $MailChimp_defaultSettings;
    public $MailChimp_optionName = array(
        'options' => 'wp_MailChimp_form_options',
        'lists' => 'wp_MailChimp_form_lists',
        'users' => 'wp_MailChimp_form_users',
    );

    function __construct() {
        parent::__construct(// Base ID of your widget
            'MailChimp-widget-form', // Widget name will appear in UI
            esc_html__('MailChimp | Widget Form', 'mailchimp-form'), // Widget description
            array('description' => esc_html__('Sidebar MailChimp Widget Form', 'mailchimp-form'),));
        /*
         * load plugin actions
         */
        add_action("wp_ajax_nopriv_MailChimp_subscribe", array(
            $this,
            'subscribe'
        ));
        add_action("wp_ajax_MailChimp_subscribe", array(
            $this,
            'subscribe'
        ));
        add_action('wp_head', array(
            $this,
            'custom_style'
        ));
    }

    // get option value by key
    public function get_options($value, $key) {
        $MailChimp_option = get_option($this->MailChimp_optionName[$key]);
        return isset($MailChimp_option[$value]) ? $MailChimp_option[$value] : '';
    }

    public function custom_style() {
        ?>
        <style id="widget-mailchimp-form-custom-style">
            <?php if ($this->get_options('widget_body_color', 'options')) { ?>
            .widget.widget_mailchimp-form .mailchimp-form {
                background-color: <?php echo $this->get_options('widget_body_color', 'options'); ?> !important;
            }

            <?php } ?>
            <?php if ($this->get_options('widget_body-border_color', 'options')) { ?>
            .widget.widget_mailchimp-form .mailchimp-form {
                border-color: <?php echo $this->get_options('widget_body-border_color', 'options'); ?> !important;
            }

            .widget.widget_mailchimp-form .mailchimp-form p.mailchimp_title {
                border-bottom-color: <?php echo $this->get_options('widget_body-border_color', 'options'); ?> !important;
            }

            <?php } ?>
            <?php if ($this->get_options('widget_title_color', 'options')) { ?>
            .widget.widget-mailchimp-form .mailchimp-form p.mailchimp_title {
                background-color: <?php echo $this->get_options('widget_title_color', 'options'); ?> !important;
            }

            <?php } ?>
            <?php if ($this->get_options('widget_body-font_color', 'options')) { ?>
            .widget.widget_mailchimp-form .mailchimp-form p.mailchimp_title {
                color: <?php echo $this->get_options('widget_body-font_color', 'options'); ?> !important;
            }

            .widget.widget_mailchimp-form .mailchimp-form {
                color: <?php echo $this->get_options('widget_body-font_color', 'options'); ?> !important;
            }

            <?php } ?>
        </style>
        <?php
    }

    // Creating widget front-end
    // This is where the action happens
    public function widget($args, $instance) {
        $title = apply_filters('widget_title', $instance['title']);
        //$form_layout = isset($instance['form_layout']) ? $instance['form_layout'] : '';
        // before and after widget arguments are defined by themes
        echo $args['before_widget'];
        ?>
        <div class="widget-mailchimp-form" id="<?php echo $this->id; ?>">
            <h2><?php echo (!empty($title)) ? $title : esc_html__('MailChimp Form', 'mailchimp-form'); ?></h2>
            <div class="mailchimp-form full-btn">
                <form action="<?php echo admin_url('admin-ajax.php'); ?>" method="post">
                    <p class="mailchimp_title"><i class="dashicons dashicons-email-alt"></i> <?php echo $this->get_options('widget_body_title', 'options'); ?></p>
                    <?php if ($this->get_options('allow_name', 'options') == 'true') { ?>
                        <div class="mailchimp-row">
                            <div class="mailchimp-col-5">
                                <input type="text" name="mailchimp_fname" id="mailchimp_fname" class="mailchimp_input" placeholder="<?php esc_html_e('First Name', 'mailchimp-form'); ?>">
                            </div>
                            <div class="mailchimp-col-5">
                                <input type="text" name="mailchimp_lname" id="mailchimp_lname" class="mailchimp_input" placeholder="<?php esc_html_e('Last Name', 'mailchimp-form'); ?>">
                            </div>
                        </div>
                    <?php } ?>
                    <?php if ($this->get_options('allow_phone', 'options') == 'true') { ?>
                        <div class="mailchimp-row">
                            <div class="mailchimp-col-10">
                                <input type="text" name="mailchimp_phone" id="mailchimp_phone" class="mailchimp_input" placeholder="<?php esc_html_e('Phone Number', 'mailchimp-form'); ?>">
                            </div>
                        </div>
                    <?php } ?>
                    <input type="email" name="mailchimp_email" id="mailchimp_email" class="mailchimp_input" placeholder="<?php esc_html_e('Email', 'mailchimp-form'); ?>" required>
                    <input type="submit" class="mailchimp_btn" value="<?php esc_html_e('Subscribe', 'mailchimp-form'); ?>">
                </form>
                <div class="loading"><i class="dashicons dashicons-update"></i></div>
                <p class="mailchimp_msg"></p>
            </div>
        </div>
        <?php
        echo $args['after_widget'];
    }

    // Widget Backend 
    public function form($instance) {
        $title = !empty($instance['title']) ? $instance['title'] : '';
        //$form_layout = isset($instance['form_layout']) ? $instance['form_layout'] : '';
        ?>
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>">
                <?php esc_html_e('Title', 'mailchimp-form'); ?>:
            </label>
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>"/>
        </p>
        <?php
        /*
          <p>
          <label for="<?php echo $this->get_field_id('title'); ?>">
          <?php esc_html_e('Form Layout', 'mailchimp-form'); ?>:
          </label>
          <select style="width:50%; display:block; text-align:center; cursor:pointer;" name="<?php echo $this->get_field_name('form_layout'); ?>" id="<?php echo $this->get_field_id('form_layout'); ?>">
          <?php for ($x = 1; $x <= 3; $x++) { ?>
          <option  value="<?php echo 'layout_' . $x; ?>" <?php selected($form_layout, 'layout_' . $x); ?>><?php echo esc_html__('Layout', 'mailchimp-form') . ' [' . $x . ']'; ?></option>
          <?php } ?>
          </select>
          </p>
         * */
    }

    // Updating widget replacing old instances with new
    public function update($new_instance, $old_instance) {
        $instance = array();
        $instance['title'] = (!empty($new_instance['title'])) ? strip_tags($new_instance['title']) : '';
        $instance['list_id'] = (!empty($new_instance['list_id'])) ? strip_tags($new_instance['list_id']) : '';
        //$instance['form_layout'] = (!empty($new_instance['form_layout']) ) ? strip_tags($new_instance['form_layout']) : '';
        return $instance;
    }

    // subscribe
    public function subscribe() {
        $f_name = (isset($_POST['mailchimp_fname']) and !empty($_POST['mailchimp_fname'])) ? strip_tags($_POST['mailchimp_fname']) : '';
        $l_name = (isset($_POST['mailchimp_lname']) and !empty($_POST['mailchimp_lname'])) ? strip_tags($_POST['mailchimp_lname']) : '';
        $phone = (isset($_POST['mailchimp_phone']) and !empty($_POST['mailchimp_phone'])) ? strip_tags($_POST['mailchimp_phone']) : '';
        $email = (isset($_POST['mailchimp_email']) and !empty($_POST['mailchimp_email'])) ? strip_tags($_POST['mailchimp_email']) : '';
        $list_id = (isset($_POST['mailchimp_listID'])) ? strip_tags($_POST['mailchimp_listID']) : $this->get_options('list_id', 'options');
        $MailChimp = new MailChimp_API($this->get_options('api_key', 'options'), $list_id, true);
        $MailChimp->subscribed($f_name, $l_name, $email, $phone);
        exit($MailChimp->message());

    }

}
